Struct Rect
pub struct Rect { /* private fields */ }Implementations
impl Rect
impl Rect
pub fn try_downcast(element: &(dyn ElementExt + 'static)) -> Option<RectElement>
pub fn color(self, color: impl Into<Color>) -> Rect
pub fn color(self, color: impl Into<Color>) -> Rect
Set the color of text rendered inside the rect and inherited by its children. See Color.
pub fn font_size(self, font_size: impl Into<FontSize>) -> Rect
pub fn font_size(self, font_size: impl Into<FontSize>) -> Rect
Set the size of text rendered inside the rect and inherited by its children. See FontSize.
pub fn overflow<S>(self, overflow: S) -> Rect
pub fn overflow<S>(self, overflow: S) -> Rect
Set whether content overflowing the rect’s bounds is clipped. See Overflow.
pub fn transform_origin(
self,
transform_origin: impl Into<TransformOrigin>,
) -> Rect
pub fn transform_origin( self, transform_origin: impl Into<TransformOrigin>, ) -> Rect
Set the point that the scale and rotation effects pivot around.
Defaults to the element’s center.